@@ -2,8 +2,8 @@
 
 #![allow(missing_docs)]
 
-use term::{Term, abs, app};
-use term::Term::*;
+use crate::term::{Term, abs, app};
+use crate::term::Term::*;
 use self::Encoding::*;
 
 /// The type of numeric encoding.
@@ -93,7 +93,7 @@ impl IntoBinaryNum for usize {
         if self != 0 {
             let binstr = format!("{:b}", self).into_bytes();
 
-            for bit in binstr.into_iter() {
+            for bit in binstr {
                 if bit == b'0' {
                     ret = app(Var(2), ret);
                 } else {
