@@ -1,12 +1,12 @@
 //! A parser for lambda expressions
 
-use term::{Term, Notation, abs, app};
-use term::Term::*;
+use crate::term::{Term, Notation, abs, app};
+use crate::term::Term::*;
 use self::Token::*;
 use self::CToken::*;
 use self::ParseError::*;
 use self::Expression::*;
-pub use term::Notation::*;
+pub use crate::term::Notation::*;
 
 /// An error returned by `parse()` when a parsing issue is encountered.
 #[derive(Debug, PartialEq)]
@@ -140,8 +140,7 @@ fn _convert_classic_tokens<'t, 's>(tokens: &'t [CToken], stack: &'s mut Vec<&'t
             },
             CRparen => {
                 output.push(Rparen);
-                let l = stack.len(); // TODO: move when NLL hits stable
-                stack.truncate(l - inner_stack_count);
+                stack.truncate(stack.len() - inner_stack_count);
                 return output
             },
             CName(ref name) => {
@@ -298,7 +297,7 @@ mod tests {
     fn tokenization_success_classic() {
         let blc_dbr = "(λ11)(λλλ1(λλλλ3(λ5(3(λ2(3(λλ3(λ123)))(4(λ4(λ31(21))))))(1(2(λ12))\
             (λ4(λ4(λ2(14)))5))))(33)2)(λ1((λ11)(λ11)))";
-        let blc_cla = format!("{}", parse(&blc_dbr, DeBruijn).unwrap());
+        let blc_cla = parse(&blc_dbr, DeBruijn).unwrap().to_string();
 
         let tokens_cla = tokenize_cla(&blc_cla);
         let tokens_dbr = tokenize_dbr(&blc_dbr);
