@@ -1,7 +1,7 @@
 //! [β-reduction](https://en.wikipedia.org/wiki/Beta_normal_form) for lambda `Term`s
 
-use term::{Term, TermError};
-use term::Term::*;
+use crate::term::{Term, TermError};
+use crate::term::Term::*;
 use std::fmt;
 use std::mem;
 pub use self::Order::*;
@@ -82,17 +82,18 @@ impl Term {
     }
 
     fn _apply(&mut self, rhs: &Term, depth: usize) {
-        match *self {
-            Var(i) => if i == depth {
+        match self {
+            Var(i) => if *i == depth {
                 *self = rhs.to_owned(); // substitute a top-level variable from lhs with rhs
                 self.update_free_variables(depth - 1, 0); // update indices of free variables from rhs
-            } else if i > depth {
-                *self = Var(i - 1) // decrement a free variable's index
+            } else if *i > depth {
+                *self = Var(*i - 1) // decrement a free variable's index
             },
             Abs(ref mut abstracted) => {
                 abstracted._apply(rhs, depth + 1)
             },
-            App(ref mut lhs_lhs, ref mut lhs_rhs) => {
+            App(boxed) => {
+                let (ref mut lhs_lhs, ref mut lhs_rhs) = **boxed;
                 lhs_lhs._apply(rhs, depth);
                 lhs_rhs._apply(rhs, depth)
             }
@@ -100,14 +101,15 @@ impl Term {
     }
 
     fn update_free_variables(&mut self, added_depth: usize, own_depth: usize) {
-        match *self {
+        match self {
             Var(ref mut i) => if *i > own_depth {
                 *i += added_depth
             },
             Abs(ref mut abstracted) => {
                 abstracted.update_free_variables(added_depth, own_depth + 1)
             },
-            App(ref mut lhs, ref mut rhs) => {
+            App(boxed) => {
+                let (ref mut lhs, ref mut rhs) = **boxed;
                 lhs.update_free_variables(added_depth, own_depth);
                 rhs.update_free_variables(added_depth, own_depth)
             }
@@ -123,8 +125,8 @@ impl Term {
         *count += 1;
     }
 
-    fn is_reducible(&self, limit: usize, count: &usize) -> bool {
-        self.lhs_ref().and_then(|t| t.unabs_ref()).is_ok() && (limit == 0 || *count < limit )
+    fn is_reducible(&self, limit: usize, count: usize) -> bool {
+        self.lhs_ref().and_then(|t| t.unabs_ref()).is_ok() && (limit == 0 || count < limit )
     }
 
     /// Performs β-reduction on a `Term` with the specified evaluation `Order` and an optional limit
@@ -162,10 +164,10 @@ impl Term {
     fn beta_cbn(&mut self, limit: usize, count: &mut usize) {
         if limit != 0 && *count == limit { return }
 
-        if let App(_, _) = *self {
+        if let App(_) = *self {
             self.lhs_mut().unwrap().beta_cbn(limit, count);
 
-            if self.is_reducible(limit, count) {
+            if self.is_reducible(limit, *count) {
                 self.eval(count);
                 self.beta_cbn(limit, count);
             }
@@ -177,10 +179,10 @@ impl Term {
 
         match *self {
             Abs(ref mut abstracted) => abstracted.beta_nor(limit, count),
-            App(_, _) => {
+            App(_) => {
                 self.lhs_mut().unwrap().beta_cbn(limit, count);
 
-                if self.is_reducible(limit, count) {
+                if self.is_reducible(limit, *count) {
                     self.eval(count);
                     self.beta_nor(limit, count);
                 } else {
@@ -195,11 +197,11 @@ impl Term {
     fn beta_cbv(&mut self, limit: usize, count: &mut usize) {
         if limit != 0 && *count == limit { return }
 
-        if let App(_, _) = *self {
+        if let App(_) = *self {
             self.lhs_mut().unwrap().beta_cbv(limit, count);
             self.rhs_mut().unwrap().beta_cbv(limit, count);
 
-            if self.is_reducible(limit, count) {
+            if self.is_reducible(limit, *count) {
                 self.eval(count);
                 self.beta_cbv(limit, count);
             }
@@ -211,11 +213,11 @@ impl Term {
 
         match *self {
             Abs(ref mut abstracted) => abstracted.beta_app(limit, count),
-            App(_, _) => {
+            App(_) => {
                 self.lhs_mut().unwrap().beta_app(limit, count);
                 self.rhs_mut().unwrap().beta_app(limit, count);
 
-                if self.is_reducible(limit, count) {
+                if self.is_reducible(limit, *count) {
                     self.eval(count);
                     self.beta_app(limit, count);
                 }
@@ -229,11 +231,11 @@ impl Term {
 
         match *self {
             Abs(ref mut abstracted) => abstracted.beta_hap(limit, count),
-            App(_, _) => {
+            App(_) => {
                 self.lhs_mut().unwrap().beta_cbv(limit, count);
                 self.rhs_mut().unwrap().beta_hap(limit, count);
 
-                if self.is_reducible(limit, count) {
+                if self.is_reducible(limit, *count) {
                     self.eval(count);
                     self.beta_hap(limit, count);
                 } else {
@@ -249,10 +251,10 @@ impl Term {
 
         match *self {
             Abs(ref mut abstracted) => abstracted.beta_hsp(limit, count),
-            App(_, _) => {
+            App(_) => {
                 self.lhs_mut().unwrap().beta_hsp(limit, count);
 
-                if self.is_reducible(limit, count) {
+                if self.is_reducible(limit, *count) {
                     self.eval(count);
                     self.beta_hsp(limit, count)
                 }
@@ -266,10 +268,10 @@ impl Term {
 
         match *self {
             Abs(ref mut abstracted) => abstracted.beta_hno(limit, count),
-            App(_, _) => {
+            App(_) => {
                 self.lhs_mut().unwrap().beta_hsp(limit, count);
 
-                if self.is_reducible(limit, count) {
+                if self.is_reducible(limit, *count) {
                     self.eval(count);
                     self.beta_hno(limit, count)
                 } else {
